@@ -1,9 +1,9 @@
-from cgi import test
 import json
 import os
 import signal
 import sys
 from threading import Thread
+import sqlite3
 
 
 def load(location, auto_dump):
@@ -25,9 +25,6 @@ class SynDB(object):
         if self.dthread is not None:
             self.dthread.join()
 
-    def __version__(self):
-        return "1.9"
-
     def __repr__(self):
         return str(self.db)
 
@@ -169,11 +166,31 @@ class SynDB(object):
         else:
             return False
 
-    def set_two(self, key, value_name, value):
-        try:
-            data = {value_name: value}
-            self.db[key] = data
+    def dcreate(self, key):
+        if isinstance(key, str):
+            self.db[key] = {}
             self._autodump()
             return True
-        except:
-            return False
\ No newline at end of file
+        else:
+            raise self.key_error
+
+    def dadd(self, key, value, value2):
+        if key in self.db:
+            self.db[key][value] = value2
+            self._autodump()
+            return True
+        else:
+            return False
+
+    def dget(self, key, value):
+        if key in self.db:
+            return self.db[key][value]
+        else:
+            return False
+
+    def dmerge(self, name, name2):
+        name1 = self.db[name]
+        name_2 = self.db[name2]
+        name1.update(name_2)
+        self._autodump()
+        return True
\ No newline at end of file
